==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/WUBA.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+12)
#define CT_v192	((void*)startLabel+48)
#define F0_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+56)
#define FN_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+68)
#define CT_v194	((void*)startLabel+92)
#define CF_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+100)
#define CT_v196	((void*)startLabel+156)
#define ST_v193	((void*)startLabel+172)
#define ST_v191	((void*)startLabel+193)
#define ST_v195	((void*)startLabel+215)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95wUBA_35(void);
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95mkIOok3[];
extern Node TM_NHC_46BinArray[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v192)
,	/* FN_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PUSH_ARG_I3,EVAL)
, bytes2word(POP_I1,PRIMITIVE,NOP,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v191)
,	/* CT_v192: (byte 0) */
  HW(0,3)
, 0
,	/* F0_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA_35),3)
, bytes2word(0,0,0,0)
, useLabel(CT_v194)
,	/* FN_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v193)
,	/* CT_v194: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok3))
, useLabel(F0_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v196)
,};
Node FN_NHC_46BinArray_46wUBA[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_ARG_I1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I3,ZAP_ARG_I1,ZAP_ARG_I2)
, bytes2word(ZAP_ARG_I3,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(3,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 140001
, useLabel(ST_v195)
,	/* CT_v196: (byte 0) */
  HW(1,3)
, 0
,};
Node F0_NHC_46BinArray_46wUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46wUBA),3)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
,	/* ST_v193: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(119,85,66,65)
,	/* ST_v191: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,119,85,66)
,	/* ST_v195: (byte 3) */
  bytes2word(65,35,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(119,85,66,65)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_wUBA" NHC.BinArray.hs_wUBA# 3 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int -> Prelude.Int */
extern HsInt hs_wUBA(void*,HsInt,HsInt);
#ifdef PROFILE
static SInfo pf_hs_wUBA = {"NHC.BinArray","NHC.BinArray.hs_wUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95wUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  HsInt arg3;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);
  nodeptr = C_GETARG1(3);
  IND_REMOVE(nodeptr);
  arg3 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_wUBA(arg1,arg2,arg3);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_wUBA);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/WUBA.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+12)
#define CT_v196	((void*)startLabel+48)
#define F0_NHC_46BinArray_46hs_95wUBA_35	((void*)startLabel+56)
#define FN_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+68)
#define CT_v198	((void*)startLabel+92)
#define CF_NHC_46BinArray_46hs_95wUBA	((void*)startLabel+100)
#define CT_v200	((void*)startLabel+156)
#define ST_v197	((void*)startLabel+172)
#define ST_v195	((void*)startLabel+193)
#define ST_v199	((void*)startLabel+215)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95wUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok3[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v196)
,	/* FN_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PUSH_ARG_I3,EVAL)
, bytes2word(POP_I1,PRIMITIVE,NOP,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v195)
,	/* CT_v196: (byte 0) */
  HW(0,3)
, 0
,	/* F0_NHC_46BinArray_46hs_95wUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA_35),3)
, bytes2word(0,0,0,0)
, useLabel(CT_v198)
,	/* FN_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v197)
,	/* CT_v198: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95wUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok3))
, useLabel(F0_NHC_46BinArray_46hs_95wUBA_35)
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v200)
,};
Node FN_NHC_46BinArray_46wUBA[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_ARG_I1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I3,ZAP_ARG_I1,ZAP_ARG_I2)
, bytes2word(ZAP_ARG_I3,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(3,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 140001
, useLabel(ST_v199)
,	/* CT_v200: (byte 0) */
  HW(1,3)
, 0
,};
Node F0_NHC_46BinArray_46wUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46wUBA),3)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95wUBA))
,	/* ST_v197: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(119,85,66,65)
,	/* ST_v195: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,119,85,66)
,	/* ST_v199: (byte 3) */
  bytes2word(65,35,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(119,85,66,65)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_wUBA" NHC.BinArray.hs_wUBA# 3 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int -> Prelude.Int */
extern HsInt hs_wUBA(void*,HsInt,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95wUBA_35 = {"NHC.BinArray","NHC.BinArray.hs_wUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95wUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  HsInt arg3;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);
  nodeptr = C_GETARG1(3);
  IND_REMOVE(nodeptr);
  arg3 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_wUBA(arg1,arg2,arg3);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95wUBA_35);
  C_RETURN(nodeptr);
}
